spannertools.fracture_spanners_that_cross_components
====================================================

.. autofunction:: abjad.tools.spannertools.fracture_spanners_that_cross_components.fracture_spanners_that_cross_components
